clear all
clc

m = 200;            % Mass of the kite (Kg)
g = 9.80665;        % Constant of gravity (m/s^2)
w = 0.25;           % Angular frequency (rad/s)
R = 70;             % Turn ratius (m)
theta = 15;         % Seat angle ()

Vw = 10;             % Wind speed (m/s)
Vl = Vw/3;          % Unwinding speed (m/s)

%% Geometric data

cr = 1.8;                                         % Root chord (m)
ct = 0.8;                                         % Tip chord (m)
b = 12;                                           % Wingspan (m)
lambda = ct/cr;                                   % Taper ratio
SMC = (cr+ct)/2;                                  % Standard Mean Chord (m)
MAC = 2/3*cr*(1+lambda+(lambda^2))/(1+lambda);    % Mean Aerodynamic Chord (m)
Sw = 2*SMC*(b/2);                                 % Wing surface (m^2)
AR = b/SMC;                                       % Aspect ratio
e = 0.9;                                          % Oswald factor

xcg = 0.7;                                        % Barycentre (m)
xac = 0.6;                                        % Aerodynamic centre (m)

% In = 6810; 
In = m/12*((SMC^2)+((0.15*SMC)^2));               % Moment of inertia (Kg*m^2)
%% Aerodynamic coefficients

Cl0 = 0.7;                     % Lift coefficient Cl0
Clalpha = 2*pi;                % Lift coefficient Clalpha
Cd0 = 0.02;                    % Drag coefficient Cd0
Cmo = 0.01;                    % Aerodynamic moment coefficient Cm0
Cmalpha = -1.4;                % Aerodynamic moment coefficient Cmalpha

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% SIMULINK MODEL MUST BE RUN %%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

t_simulation = 180;           % Simulation time introduced in s
t_step = 0.01;               % Fixed time step introduced in s

sim('ascendinghelix');

t = tout;

%% Speed Graphs

% Wind Speed (m/s)

for i = 1:length(t)
    Vwvec(i) = Vw;
end

figure(1)
plot(t,Vwvec)
grid
xlabel('time (s)','interpreter','latex')
ylabel('Wind Speed (m/s)','interpreter','latex')

% Aerodynamic Speed (m/s)

figure(2)
plot(t,ChidotR)
grid
xlabel('time (s)','interpreter','latex')
ylabel('$\stackrel{.}{\chi}$R (m/s)','interpreter','latex')

% Speed of the kite (m/s)

figure(3)
plot(t,Vx)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${V}_{x}$ (m/s)','interpreter','latex')

figure(4)
plot(t,Vy)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${V}_{y}$ (m/s)','interpreter','latex')

figure(5)
plot(t,Vz)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${V}_{z}$ (m/s)','interpreter','latex')

% Aerodynamic Speed squared

figure(6)
plot(t,V2)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${V}^{2}$ (${m}^{2}$/${s}^{2}$)','interpreter','latex')

%% Trajectory Graphs

figure(7)
plot(t,x)
grid
xlabel('time (s)','interpreter','latex')
ylabel('x (m)','interpreter','latex')

figure(8)
plot(t,y)
grid
xlabel('time (s)','interpreter','latex')
ylabel('y (m)','interpreter','latex')

figure(9)
plot(t,z)
grid
xlabel('time (s)','interpreter','latex')
ylabel('z (m)','interpreter','latex')

figure(10)
plot(x,y)
grid
xlabel('x (m)','interpreter','latex')
ylabel('y (m)','interpreter','latex')

figure(11)
plot(x,z)
grid
xlabel('x (m)','interpreter','latex')
ylabel('z (m)','interpreter','latex')

figure(12)
plot(y,z)
grid
xlabel('y (m)','interpreter','latex')
ylabel('z (m)','interpreter','latex')

figure(13)
plot3(x,y,z)
grid
xlabel('x (m)','interpreter','latex')
ylabel('y (m)','interpreter','latex')
zlabel('z (m)','interpreter','latex')

%% Angular Positioning

% Angle of Sideslip ()

figure(14)
plot(t,Beta)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\beta}$ ($^{\circ}$)','interpreter','latex')

% Angle of the cylinder axis ()

figure(15)
plot(t,Epsilon)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\epsilon}$ ($^{\circ}$)','interpreter','latex')

% Seat angle ()

figure(16)
plot(t,Theta)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\theta}$ ($^{\circ}$)','interpreter','latex')

% Angle of attack ()

figure(17)
plot(t,Alpha)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\alpha}$ ($^{\circ}$)','interpreter','latex')

% Angular speed of the angle of attack (rad/s)

figure(18)
plot(t,Alphadot)
grid
xlabel('time (s)','interpreter','latex')
ylabel('$\stackrel{.}{\alpha}$ (rad/s)','interpreter','latex')

% Seat angle of speed ()

figure(19)
plot(t,Gamma)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\gamma}$ ($^{\circ}$)','interpreter','latex')

% Angular speed of the seat angle of speed (rad/s)

figure(20)
plot(t,Gammadot)
grid
xlabel('time (s)','interpreter','latex')
ylabel('$\stackrel{.}{\gamma}$ (rad/s)','interpreter','latex')

% Angle of rotation ()

figure(21)
plot(t,Chi)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\chi}$ ($^{\circ}$)','interpreter','latex')

% Angular speed of the angle of rotation (rad/s)

figure(22)
plot(t,Chidot)
grid
xlabel('time (s)','interpreter','latex')
ylabel('$\stackrel{.}{\chi}$ (rad/s)','interpreter','latex')

% Roll angle ()

figure(23)
plot(t,Nu)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${\mu}$ ($^{\circ}$)','interpreter','latex')

%% Air density (kg/m^3)

figure(24)
plot(z,Rho)
grid
xlabel('Height h (m)','interpreter','latex')
ylabel('Density ${\rho}$ (Kg/${m}^{3}$)','interpreter','latex')

%% Aerodynamic Contributions

% Aerodynamic coefficients

figure(25)
plot(t,CL)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${C}_{L}$','interpreter','latex')

figure(26)
plot(t,CD)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${C}_{D}$','interpreter','latex')

figure(27)
plot(t,Cmac)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${C}_{mac}$','interpreter','latex')

% Aerodynamic Forces and Moment

figure(28)
plot(t,Lift)
grid
xlabel('time (s)','interpreter','latex')
ylabel('L (N)','interpreter','latex')

figure(29)
plot(t,Drag)
grid
xlabel('time (s)','interpreter','latex')
ylabel('D (N)','interpreter','latex')

figure(30)
plot(t,Mac)
grid
xlabel('time (s)','interpreter','latex')
ylabel('${M}_{ac}$ (Nm)','interpreter','latex')

%% Cable length

figure(31)
plot(t,s)
grid
xlabel('time (s)','interpreter','latex')
ylabel('Cable Length s (m)','interpreter','latex')

%% Traction

figure(32)
plot(t,Traction)
grid
xlabel('time (s)','interpreter','latex')
ylabel('Traction T (N)','interpreter','latex')

%% Active Power

for i=1:length(Active_Power)
   if Traction(i)<0
        Active_Power(i) = 0;
   end
end
figure(33)
plot(t,Active_Power)
grid
xlabel('time (s)','interpreter','latex')
ylabel('Active Power ${P}_{a}$ (W)','interpreter','latex')

Paverg = mean(Active_Power)/1e3;                    % in kW
Eactive = trapz(t_step,Active_Power)/(3.6e6);       % in Kwh

clc